VulnerableCode documentation
=============================

Welcome to VulnerableCode! In this documentation you’ll find information on:

- An overview of VulnerableCode
- Installation instructions
- How to make technical contributions to the project and the community

.. toctree::
    :maxdepth: 2
    :caption: Getting Started

    introduction
    installation
    contributing
    faq
    misc

.. toctree::
   :maxdepth: 2
   :caption: Tutorial

   tutorial_add_new_importer
   tutorial_add_new_improver


.. toctree::
    :maxdepth: 2
    :caption: Reference Documentation

    reference_importer_overview
    reference_improver_overview
    reference_framework_overview
    command-line-interface

.. toctree::
   :maxdepth: 1
   :caption: Summer of Codes

   soc_gsoc21

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
